#include <fstream>
#include <string>
#include "image_io.h"
#include "rasterize_triangles.h"

int main(int argc, char** argv)
{
   for(int i=1; i<argc; ++i){
      std::ifstream input(argv[i]);
      if(!input){
         std::cout<<"error opening file "<<argv[i]<<std::endl;
         continue;
      }
      std::cout<<argv[i]<<std::endl;
      // name of output image
      std::string image_filename;
      input>>image_filename;
      std::cout<<" - output image: "<<image_filename<<std::endl;
      // dimensions of image
      int ni, nj;
      input>>ni>>nj;
      std::cout<<" - dimensions: "<<ni<<" x "<<nj<<std::endl;
      // start rasterizing
      Array2<Vec3f> img(ni, nj, Vec3f(0,0,0));
      while(input){
         std::string label;
         input>>label;
         if(!input) break; // nothing more to read
         if(label.compare("ct")==0){ // constant color triangle
            Vec3f color;
            Vec2f x0, x1, x2;
            input>>color>>x0>>x1>>x2;
            rasterize_constant_color_triangle(img, color, x0, x1, x2);
         }else if(label.compare("lt")==0){ // linear color triangle
            Vec3f color0, color1, color2;
            Vec2f x0, x1, x2;
            input>>color0>>x0>>color1>>x1>>color2>>x2;
            rasterize_linear_color_triangle(img, color0, x0, color1, x1, color2, x2);
         }else{
            std::cout<<" - unexpected label "<<label<<std::endl;
            break;
         }
      }
      // write out the image
      std::cout<<" - finished rasterization"<<std::endl;
      write_sgi_compressed(img, "%s", image_filename.c_str());
   }
   return 0;
}

